Authors
=======

Praekelt Foundation
-------------------
* Shaun Sephton

bTaylor Design
--------------
* `Brandon Taylor <http://btaylordesign.com/>`_

Other
-----
* Brooks Travis
* `Denis Mishchishin <https://github.com/denz>`_

